# Daystar
Daystar is a python library that provides a convenient class for Solar calculations based off of my other library _Solarflare_. Check out Solarflare at https://pypi.org/project/Solarflare/

In order to use this library, just create an instance of the daystar class:

```python
from Daystar import *
sun = Daystar(latitude, longitude)
```

The functions provided are (they all default to datetime.datetime.now()):
  - `risetime(date)`: returns the sunrise 
  - `settime(date)`: returns the sunset
  - `solarnoon(date)`: returns the solar noon time
  - `hrangle(date)`: returns the hour angle for the time and date
  - `coordinates(date)`: returns a dictionary with declination and right ascension ("dec" and "ra")
  - `mean(date)`: returns the mean anomaly
  - `true(date)`: returns the true anomaly
  - `ceq(date)`: returns the equation of center
  - `solar_julian(date)`: returns "rise" and "set" dictionary with sunrise and sunset julian dates
  - `alt(date)`: returns solar altitude
  - `azi(date)`: returns the solar azimuth
  - `nadir(date)`: returns the time of nadir